# Experimental: Knowledge Graph

**Status**: EXPERIMENTAL - Frozen in v1.0

This directory contains experimental knowledge graph integration (HippoRAG-inspired).

These features are not actively maintained in v1.0.
